Hello!

This repo represent the current working proposal for v1.1 of the Common Workflow Language standard.

Proposed changes that aren't yet implemented are tracked at https://github.com/common-workflow-language/common-workflow-language/milestone/6

You can render this using https://github.com/common-workflow-language/cwl-website/blob/master/website.sh

The current rendering is at https://www.commonwl.org/v1.1.0-dev1/
